OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Error al interpretar la bitácora",
    "Copy" : "Copiar",
    "Copy raw" : "Copiar simple",
    "Copy formatted" : "Copiar formateado",
    "No server logs" : "No hay bitácoras del servidor",
    "One or more entries are hidden by the log level filter" : "Uno o más elementos están ocultos por el filtro del nivel de bitácora",
    "Everything is working fine" : "Todo está funcionado correctamente",
    "Log levels" : "Niveles de bitácoras",
    "Log content" : "Contenido de bitácoras",
    "Live update" : "Actualización en vivo",
    "Download logs" : "Descargar bitácoras",
    "Logging" : "Registro",
    "Log Reader" : "Lector de Bitácoras",
    "A log reader for Nextcloud" : "Un lector de bitácoras para Nextcloud",
    "Log reader for Nextcloud" : "Lector de bitácoras para Nextcloud",
    "Cased by " : "Casos por"
},
"nplurals=2; plural=(n != 1);");
